@@ -35,10 +35,12 @@
 #include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-error-bar.h>
 #include <goffice/graph/gog-series-lines.h>
+#include <goffice/graph/gog-3d-box.h>
 #include <goffice/data/go-data-simple.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-format.h>
 #include <goffice/utils/go-font.h>
+#include <goffice/app/go-conf.h>
 #include <goffice/app/go-plugin-service.h>
 #include <goffice/component/go-component-factory.h>
 #include <gsf/gsf-utils.h>
@@ -100,6 +102,7 @@ libgoffice_init ()
 
 	bindtextdomain (GETTEXT_PACKAGE, libgoffice_locale_dir);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	go_conf_init ();
 	go_fonts_init ();
 	go_math_init ();
 	gsf_init ();
@@ -126,6 +129,7 @@ libgoffice_init ()
 	(void) GOG_SERIES_LINES_TYPE;
 	(void) GO_DATA_SCALAR_VAL_TYPE;
 	(void) GO_DATA_SCALAR_STR_TYPE;
+	(void) GOG_3D_BOX_TYPE;
 	gog_themes_init	();
 	go_number_format_init ();
 	go_currency_date_format_init ();
@@ -137,6 +141,7 @@ libgoffice_shutdown (void)
 {
 	gog_themes_shutdown ();
 	go_fonts_shutdown ();
+	go_conf_shutdown ();
 #ifdef GOFFICE_WITH_GTK
 	goc_plugin_services_shutdown ();
 #endif
