@@ -298,9 +298,11 @@ gog_axis_base_get_crossed_axis (GogAxisBase *axis_base)
 	GogAxis *crossed_axis = NULL;
 	GSList *axes, *ptr;
 	gboolean found = FALSE;
+	GogAxisType axis_type = gog_axis_base_get_crossed_axis_type (axis_base);
 
-	axes = gog_chart_get_axes (axis_base->chart,
-		gog_axis_base_get_crossed_axis_type (axis_base));
+	if (axis_type == GOG_AXIS_UNKNOWN)
+		return NULL;
+	axes = gog_chart_get_axes (axis_base->chart, axis_type);
 	g_return_val_if_fail (axes != NULL, NULL);
 
 	for (ptr = axes; ptr != NULL && !found; ptr = ptr->next) {
@@ -379,6 +381,8 @@ gog_axis_base_get_clamped_position (GogAxisBase *axis_base)
 		double minimum, maximum;
 
 		cross_axis = gog_axis_base_get_crossed_axis (axis_base);
+		if (cross_axis == NULL)
+			return GOG_AXIS_AUTO;
 		cross_location = gog_axis_base_get_cross_location (axis_base);
 		if (gog_axis_get_bounds (cross_axis, &minimum, &maximum)) {
 			if (go_sub_epsilon (cross_location - minimum) <= 0.0)
@@ -1496,7 +1500,6 @@ x_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 	GogAxisType axis_type = gog_axis_get_atype (axis_base->axis);
 	GogChartMap *c_map;
 	GogAxisMap *a_map;
-	GogViewAllocation tmp = *plot_area;
 	GogViewAllocation axis_line_bbox;
 	double ax, ay, bx, by;
 	double start, stop;
@@ -1525,10 +1528,10 @@ x_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 							     view->renderer, ax, ay, bx - ax, by - ay, 
 							     GO_SIDE_RIGHT, -1.,
 							     axis_base->major_tick_labeled);
-			padding->wl = MAX (0., tmp.x - axis_line_bbox.x);
-			padding->ht = MAX (0., tmp.y - axis_line_bbox.y);
-			padding->wr = MAX (0., axis_line_bbox.x + axis_line_bbox.w - tmp.x - tmp.w);
-			padding->hb = MAX (0., axis_line_bbox.y + axis_line_bbox.h - tmp.y - tmp.h);
+			padding->wl = MAX (0., plot_area->x - axis_line_bbox.x);
+			padding->ht = MAX (0., plot_area->y - axis_line_bbox.y);
+			padding->wr = MAX (0., axis_line_bbox.x + axis_line_bbox.w - plot_area->x - plot_area->w);
+			padding->hb = MAX (0., axis_line_bbox.y + axis_line_bbox.h - plot_area->y - plot_area->h);
 			break;
 
 		case GOG_AXIS_BASE_POINT:
@@ -1550,7 +1553,6 @@ xy_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 	GogAxis *cross_axis;
 	GogChartMap *c_map;
 	GogAxisMap *a_map;
-	GogViewAllocation tmp = *plot_area;
 	GogViewAllocation axis_line_bbox;
 	double ax, ay, bx, by;
 	GogAxisType axis_type = gog_axis_get_atype (axis_base->axis);
@@ -1619,10 +1621,10 @@ xy_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 			axis_line_bbox = axis_line_get_bbox (GOG_AXIS_BASE (view->model),
 							     view->renderer, ax, ay, bx - ax, by - ay, side, -1.,
 							     axis_base->major_tick_labeled);
-			padding->wl = MAX (0., tmp.x - axis_line_bbox.x);
-			padding->ht = MAX (0., tmp.y - axis_line_bbox.y);
-			padding->wr = MAX (0., axis_line_bbox.x + axis_line_bbox.w - tmp.x - tmp.w);
-			padding->hb = MAX (0., axis_line_bbox.y + axis_line_bbox.h - tmp.y - tmp.h);
+			padding->wl = MAX (0., plot_area->x - axis_line_bbox.x);
+			padding->ht = MAX (0., plot_area->y - axis_line_bbox.y);
+			padding->wr = MAX (0., axis_line_bbox.x + axis_line_bbox.w - plot_area->x - plot_area->w);
+			padding->hb = MAX (0., axis_line_bbox.y + axis_line_bbox.h - plot_area->y - plot_area->h);
 			break;
 
 		case GOG_AXIS_BASE_POINT:
@@ -1646,7 +1648,6 @@ radar_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 	GogAxisMap *a_map;
 	GogAxisType axis_type = gog_axis_get_atype (axis_base->axis);
 	GogChartMapPolarData *parms;
-	GogViewAllocation tmp = *area;
 	GogViewAllocation bbox;
 	GOGeometrySide side;
 	double start, stop, minimum, maximum;
@@ -1710,10 +1711,10 @@ radar_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 					view->renderer, parms->cx, parms->cy,
 					bx - parms->cx, by - parms->cy, side, -1.,
 					axis_base->major_tick_labeled);
-				padding->wl = MAX (0., tmp.x - bbox.x);
-				padding->ht = MAX (0., tmp.y - bbox.y);
-				padding->wr = MAX (0., bbox.x + bbox.w - tmp.x - tmp.w);
-				padding->hb = MAX (0., bbox.y + bbox.h - tmp.y - tmp.h);
+				padding->wl = MAX (0., area->x - bbox.x);
+				padding->ht = MAX (0., area->y - bbox.y);
+				padding->wr = MAX (0., bbox.x + bbox.w - area->x - area->w);
+				padding->hb = MAX (0., bbox.y + bbox.h - area->y - area->h);
 				break;
 			case GOG_AXIS_BASE_POINT:
 				if (gog_axis_is_discrete (cross_axis))
@@ -1750,10 +1751,10 @@ radar_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 			case GOG_AXIS_BASE_PADDING_REQUEST:
 				bbox = axis_circle_get_bbox (axis_base, view->renderer, c_map,
 							     axis_base->major_tick_labeled);
-				padding->wl = MAX (0., tmp.x - bbox.x);
-				padding->ht = MAX (0., tmp.y - bbox.y);
-				padding->wr = MAX (0., bbox.x + bbox.w - tmp.x - tmp.w);
-				padding->hb = MAX (0., bbox.y + bbox.h - tmp.y - tmp.h);
+				padding->wl = MAX (0., area->x - bbox.x);
+				padding->ht = MAX (0., area->y - bbox.y);
+				padding->wr = MAX (0., bbox.x + bbox.w - area->x - area->w);
+				padding->hb = MAX (0., bbox.y + bbox.h - area->y - area->h);
 				break;
 			case GOG_AXIS_BASE_POINT:
 				point = axis_circle_point (x, y, parms->cx, parms->cy, parms->rx, parms->th1);
@@ -1764,6 +1765,20 @@ radar_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 	return point;
 }
 
+static gboolean
+xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
+	    GogViewAllocation const *plot_area, double x, double y)
+{
+    GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
+    GogAxisType axis_type = gog_axis_get_atype (axis_base->axis);
+    g_return_val_if_fail (axis_type == GOG_AXIS_X ||
+			  axis_type == GOG_AXIS_Y ||
+			  axis_type == GOG_AXIS_Z, FALSE);
+
+    return TRUE;
+
+}
+
 static gboolean
 gog_axis_base_view_point (GogView *view, double x, double y)
 {
@@ -1799,6 +1814,9 @@ gog_axis_base_view_point (GogView *view, double x, double y)
 		case GOG_AXIS_SET_RADAR:
 			pointed = radar_process (GOG_AXIS_BASE_POINT, view, NULL, plot_area, x, y);
 			break;
+		case GOG_AXIS_SET_XYZ:
+			xyz_process (GOG_AXIS_BASE_PADDING_REQUEST, view, NULL, plot_area, x, y);
+			break;
 		default:
 			g_warning ("[AxisBaseView::point] not implemented for this axis set (%i)",
 				   axis_set);
@@ -1833,6 +1851,8 @@ gog_axis_base_view_padding_request (GogView *view, GogViewAllocation const *bbox
 		case GOG_AXIS_SET_RADAR:
 			radar_process (GOG_AXIS_BASE_PADDING_REQUEST, view, padding, bbox, 0., 0.);
 			break;
+		case GOG_AXIS_SET_XYZ:
+			break;
 		default:
 			g_warning ("[AxisBaseView::padding_request] not implemented for this axis set (%i)",
 				   axis_set);
