@@ -41,10 +41,34 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkcombobox.h>
 #endif
 
 #include <string.h>
 
+/* Keep in sync with GogSeriesFillType enum */
+static struct {
+	GogSeriesFillType  type;
+	char const 	  *name;
+	char const 	  *label;
+} _fill_type_infos[] = {
+	{GOG_SERIES_FILL_TYPE_Y_ORIGIN,	"y-origin",	N_("Y origin")},
+	{GOG_SERIES_FILL_TYPE_X_ORIGIN,	"x-origin",	N_("X origin")},
+	{GOG_SERIES_FILL_TYPE_BOTTOM,	"bottom",	N_("Bottom")},
+	{GOG_SERIES_FILL_TYPE_LEFT,	"left",		N_("Left")},
+	{GOG_SERIES_FILL_TYPE_TOP,	"top",		N_("Top")},
+	{GOG_SERIES_FILL_TYPE_RIGHT,	"right",	N_("Right")},
+	{GOG_SERIES_FILL_TYPE_ORIGIN,	"origin",	N_("Origin")},
+	{GOG_SERIES_FILL_TYPE_CENTER,	"center",	N_("Center")},
+	{GOG_SERIES_FILL_TYPE_EDGE,	"edge",		N_("Edge")},
+	{GOG_SERIES_FILL_TYPE_SELF,	"self",		N_("Self")},
+	{GOG_SERIES_FILL_TYPE_NEXT,	"next",		N_("Next series")},
+	{GOG_SERIES_FILL_TYPE_INVALID,	"invalid",	""}
+};
+
+#ifdef GOFFICE_WITH_GTK
+#endif
+
 int gog_series_get_valid_element_index (GogSeries const *series, int old_index, int desired_index);
 
 /*****************************************************************************/
@@ -201,10 +225,11 @@ gog_series_element_class_init (GogSeriesElementClass *klass)
 	gog_klass->use_parent_as_proxy  = TRUE;
 
 	g_object_class_install_property (gobject_klass, ELEMENT_INDEX,
-		g_param_spec_int ("index", "index",
-			"Index of the corresponding data element",
+		g_param_spec_int ("index", 
+			_("Index"),
+			_("Index of the corresponding data element"),
 			0, G_MAXINT, 0,
-			G_PARAM_READWRITE | GOG_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 }
 
 GSF_CLASS (GogSeriesElement, gog_series_element,
@@ -237,7 +262,9 @@ static GObjectClass *series_parent_klass;
 
 enum {
 	SERIES_PROP_0,
-	SERIES_HAS_LEGEND
+	SERIES_PROP_HAS_LEGEND,
+	SERIES_PROP_INTERPOLATION,
+	SERIES_PROP_FILL_TYPE
 };
 
 static gboolean
@@ -305,9 +332,11 @@ gog_series_set_property (GObject *obj, guint param_id,
 {
 	GogSeries *series = GOG_SERIES (obj);
 	gboolean b_tmp;
+	char const *name;
+	unsigned int i;
 
 	switch (param_id) {
-	case SERIES_HAS_LEGEND :
+	case SERIES_PROP_HAS_LEGEND :
 		b_tmp = g_value_get_boolean (value);
 		if (series->has_legend ^ b_tmp) {
 			series->has_legend = b_tmp;
@@ -315,6 +344,16 @@ gog_series_set_property (GObject *obj, guint param_id,
 				gog_plot_request_cardinality_update (series->plot);
 		}
 		break;
+	case SERIES_PROP_INTERPOLATION:
+		series->interpolation = go_line_interpolation_from_str (g_value_get_string (value));
+		break;
+	case SERIES_PROP_FILL_TYPE:
+		name = g_value_get_string (value);
+		for (i = 0; i < G_N_ELEMENTS (_fill_type_infos); i++)
+			if (strcmp (_fill_type_infos[i].name, name) == 0)
+			       series->fill_type = _fill_type_infos[i].type;
+		break;
+
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 return; /* NOTE : RETURN */
 	}
@@ -329,9 +368,16 @@ gog_series_get_property (GObject *obj, guint param_id,
 	GogSeries *series = GOG_SERIES (obj);
 
 	switch (param_id) {
-	case SERIES_HAS_LEGEND :
+	case SERIES_PROP_HAS_LEGEND :
 		g_value_set_boolean (value, series->has_legend);
 		break;
+	case SERIES_PROP_INTERPOLATION:
+		g_value_set_string (value, go_line_interpolation_as_str (series->interpolation));
+		break;
+	case SERIES_PROP_FILL_TYPE:
+		g_value_set_string (value, _fill_type_infos[series->fill_type].name);
+		break;
+
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
 	}
@@ -367,6 +413,20 @@ cb_show_in_legend (GtkToggleButton *b, GObject *series)
 		NULL);
 }
 
+static void
+cb_line_interpolation_changed (GtkComboBox *box, GogSeries *series)
+{
+	series->interpolation = gtk_combo_box_get_active (box);
+	gog_object_emit_changed (GOG_OBJECT (series), FALSE);
+}
+
+static void
+cb_fill_type_changed (GtkComboBox *combo, GObject *obj)
+{
+	gog_series_set_fill_type (GOG_SERIES (obj),
+				  gog_series_get_fill_type_from_combo (GOG_SERIES (obj), combo));
+}
+
 static void
 gog_series_populate_editor (GogObject *gobj,
 			    GogEditor *editor,
@@ -374,11 +434,12 @@ gog_series_populate_editor (GogObject *gobj,
 		   GOCmdContext *cc)
 {
 	static guint series_pref_page = 1;
-	GtkWidget *w;
+	GtkWidget *w, *box;
 	GtkTable  *table;
 	unsigned i, row = 0;
 	gboolean has_shared = FALSE;
 	GogSeries *series = GOG_SERIES (gobj);
+	GogSeriesClass *series_class = GOG_SERIES_GET_CLASS (series);
 	GogDataset *set = GOG_DATASET (gobj);
 	GogSeriesDesc const *desc;
 	GogDataType data_type;
@@ -446,6 +507,42 @@ gog_series_populate_editor (GogObject *gobj,
 
 	(GOG_OBJECT_CLASS(series_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 
+	box = gog_editor_get_registered_widget (editor, "line_box");
+	if (series_class->has_interpolation && box != NULL) {
+		GladeXML *gui;
+		GtkWidget *widget;
+
+		gui = go_libglade_new ("gog-series-prefs.glade", "interpolation_prefs", GETTEXT_PACKAGE, cc);
+		if (gui != NULL) {
+			widget = glade_xml_get_widget (gui, "interpolation_prefs");
+			gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 0);
+			widget = glade_xml_get_widget (gui, "interpolation_combo");
+			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), series->interpolation);
+			g_signal_connect (widget, "changed",
+					  G_CALLBACK (cb_line_interpolation_changed), series);
+			g_object_set_data_full (G_OBJECT (widget), "gui", gui,
+						(GDestroyNotify) g_object_unref);
+		}
+	}
+
+	box = gog_editor_get_registered_widget (editor, "fill_extension_box");
+	if (series_class->has_fill_type && box != NULL) {
+		GladeXML *gui;
+		GtkWidget *widget;
+
+		gui = go_libglade_new ("gog-series-prefs.glade", "fill_type_prefs", GETTEXT_PACKAGE, cc);
+		if (gui != NULL) {
+			widget = glade_xml_get_widget (gui, "fill_type_combo");
+			gog_series_populate_fill_type_combo (GOG_SERIES (series), GTK_COMBO_BOX (widget));
+			g_signal_connect (G_OBJECT (widget), "changed",
+					  G_CALLBACK (cb_fill_type_changed), series);
+			widget = glade_xml_get_widget (gui, "fill_type_prefs");
+			gtk_box_pack_start (GTK_BOX (box), widget, TRUE, TRUE, 0);
+			g_object_set_data_full (G_OBJECT (widget), "gui", gui,
+						(GDestroyNotify) g_object_unref);
+		}
+	}
+
 	gog_editor_set_store_page (editor, &series_pref_page);
 }
 #endif
@@ -493,6 +590,7 @@ gog_series_class_init (GogSeriesClass *klass)
 		  regression_curve_pre_remove,
 		  NULL },
 	};
+	unsigned int i;
 
 	GObjectClass *gobject_klass = (GObjectClass *) klass;
 	GogObjectClass *gog_klass = (GogObjectClass *) klass;
@@ -502,6 +600,7 @@ gog_series_class_init (GogSeriesClass *klass)
 	gobject_klass->finalize		= gog_series_finalize;
 	gobject_klass->set_property	= gog_series_set_property;
 	gobject_klass->get_property	= gog_series_get_property;
+	klass->has_interpolation	= FALSE;
 
 #ifdef GOFFICE_WITH_GTK
 	gog_klass->populate_editor	= gog_series_populate_editor;
@@ -513,11 +612,30 @@ gog_series_class_init (GogSeriesClass *klass)
 
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
-	g_object_class_install_property (gobject_klass, SERIES_HAS_LEGEND,
-		g_param_spec_boolean ("has-legend", "has-legend",
-			"Should the series show up in legends",
+	g_object_class_install_property (gobject_klass, SERIES_PROP_HAS_LEGEND,
+		g_param_spec_boolean ("has-legend", 
+			_("Has-legend"),
+			_("Should the series show up in legends"),
 			TRUE,
-			G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+        g_object_class_install_property (gobject_klass, SERIES_PROP_INTERPOLATION,
+		 g_param_spec_string ("interpolation",
+			_("Interpolation"),
+			_("Type of line interpolation"),
+			"linear",
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, SERIES_PROP_FILL_TYPE,
+		g_param_spec_string ("fill-type", 
+			_("Fill type"),
+			_("How to fill the area"),
+			"invalid",
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+
+	klass->valid_fill_type_list = NULL;
+
+	/* Check for consistency between enum and infos */
+	for (i = 0; i < G_N_ELEMENTS (_fill_type_infos); i++)
+		g_assert (_fill_type_infos[i].type == i);
 }
 
 static void
@@ -529,6 +647,7 @@ gog_series_init (GogSeries *series)
 	series->values = NULL;
 	series->index = -1;
 	series->acceptable_children = 0;
+	series->interpolation = GO_LINE_INTERPOLATION_LINEAR;
 }
 
 static void
@@ -546,8 +665,11 @@ static GogDatasetElement *
 gog_series_dataset_get_elem (GogDataset const *set, int dim_i)
 {
 	GogSeries const *series = GOG_SERIES (set);
-	g_return_val_if_fail ((int)series->plot->desc.series.num_dim > dim_i, NULL);
+
 	g_return_val_if_fail (dim_i >= -1, NULL);
+
+	if (dim_i >= (int)series->plot->desc.series.num_dim)
+		return NULL;
 	return series->values + dim_i;
 }
 
@@ -560,6 +682,7 @@ gog_series_dataset_set_dim (GogDataset *set, int dim_i,
 	GogGraph *graph = gog_object_get_graph (GOG_OBJECT (series));
 
 	g_return_if_fail (IS_GOG_PLOT (series->plot));
+	g_return_if_fail (dim_i >= -1);
 
 	if (dim_i < 0) {
 		char *name = NULL;
@@ -575,6 +698,8 @@ gog_series_dataset_set_dim (GogDataset *set, int dim_i,
 	/* clone shared dimensions into other series in the plot, and
 	 * invalidate if necessary */
 	desc = &series->plot->desc.series;
+	g_return_if_fail (dim_i < (int) desc->num_dim);
+
 	if (desc->dim[dim_i].is_shared) {
 		GSList *ptr = series->plot->series;
 
@@ -638,7 +763,7 @@ GSF_CLASS_FULL (GogSeries, gog_series,
  * gog_series_get_plot :
  * @series : #GogSeries
  *
- * Returns the possibly NULL plot that contains this series.
+ * Returns: the possibly NULL plot that contains this series.
  **/
 GogPlot *
 gog_series_get_plot (GogSeries const *series)
@@ -651,7 +776,7 @@ gog_series_get_plot (GogSeries const *series)
  * gog_series_is_valid :
  * @series : #GogSeries
  *
- * Returns the current cached validity.  Does not recheck
+ * Returns: the current cached validity.  Does not recheck
  **/
 gboolean
 gog_series_is_valid (GogSeries const *series)
@@ -691,7 +816,7 @@ gog_series_check_validity (GogSeries *series)
  * gog_series_has_legend :
  * @series : #GogSeries
  *
- * Returns TRUE if the series has a visible legend entry
+ * Returns: TRUE if the series has a visible legend entry
  **/
 gboolean
 gog_series_has_legend (GogSeries const *series)
@@ -703,10 +828,10 @@ gog_series_has_legend (GogSeries const *series)
 /**
  * gog_series_set_index :
  * @series: #GogSeries
- * @ind:
- * @is_manual:
+ * @ind: >= 0 assigns a new index, < 0 resets to auto
+ * @is_manual: gboolean
  *
- * If @index >= 0 attempt to assign the new index.  Auto
+ * If @ind >= 0 attempt to assign the new index.  Auto
  * indicies (@is_manual == FALSE) will not override the current
  * index if it is manual.  An @index < 0, will reset the index to
  * automatic and potentially queue a revaluation of the parent
@@ -762,14 +887,13 @@ gog_series_get_name (GogSeries const *series)
 void
 gog_series_set_name (GogSeries *series, GODataScalar *name_src, GError **err)
 {
-	gog_dataset_set_dim (GOG_DATASET (series),
-		-1, GO_DATA (name_src), NULL);
+	gog_dataset_set_dim (GOG_DATASET (series), -1, GO_DATA (name_src), err);
 }
 
 /**
  * gog_series_set_dim :
  * @series : #GogSeries
- * @dim_i :
+ * @dim_i : Which dimension
  * @val   : #GOData
  * @err : optional #Gerror pointer
  *
@@ -785,7 +909,7 @@ gog_series_set_dim (GogSeries *series, int dim_i, GOData *val, GError **err)
  * gog_series_num_elements :
  * @series : #GogSeries
  *
- * Returns the number of elements in the series
+ * Returns: the number of elements in the series
  **/
 unsigned
 gog_series_num_elements (GogSeries const *series)
@@ -852,28 +976,146 @@ gog_series_get_element (GogSeries const *series, int index)
 	return NULL;
 }
 
+static unsigned int
+gog_series_get_data (GogSeries const *series, int *indices, double **data, int n_vectors)
+{
+	GODataVector *vector;
+	int i, n_points = 0, vector_n_points;
+	int first, last;
+	int index;
+	gboolean is_set = FALSE;
+
+	if (!gog_series_is_valid (series))
+		return 0;
+
+	gog_dataset_dims (GOG_DATASET (series), &first, &last);
+
+	for (i = 0; i < n_vectors; i++) {
+		index = indices != NULL ? indices[i] : i;
+		if (index >= first && index <= last &&
+		    (vector = GO_DATA_VECTOR (series->values[index].data)) != NULL) {
+			data[i] = go_data_vector_get_values (vector);
+			vector_n_points = go_data_vector_get_len (vector);
+			if (!is_set) {
+				is_set = TRUE;
+				n_points = vector_n_points;
+			} else
+				n_points = MIN (vector_n_points, n_points);
+		} else
+			data[i] = NULL;
+	}	
+
+	return n_points;
+}
+
 unsigned
-gog_series_get_xy_data (GogSeries const *series,
-					double const **x, double const **y)
+gog_series_get_xy_data (GogSeries const  *series,
+			double const 	**x, 
+			double const 	**y)
 {
 	GogSeriesClass	*klass = GOG_SERIES_GET_CLASS (series);
-	int first, last, res, nb;
-	g_return_val_if_fail (gog_series_is_valid (GOG_SERIES (series)), 0);
-	gog_dataset_dims (GOG_DATASET (series), &first, &last);
-	g_return_val_if_fail (last >= 1, 0);
-	if (klass->get_xy_data != NULL)
+	double *data[2];
+	unsigned int n_points;
+
+	g_return_val_if_fail (klass != NULL, 0);
+
+	if (klass->get_xy_data != NULL) {
+		int first, last;
+
+		if (!gog_series_is_valid (GOG_SERIES (series)))
+			return 0;
+
+		gog_dataset_dims (GOG_DATASET (series), &first, &last);
+
+		g_return_val_if_fail (first <= 0, 0);
+		g_return_val_if_fail (last >= 1, 0);
+
 		return (klass->get_xy_data) (series, x, y);
-	*y = go_data_vector_get_values (
-		GO_DATA_VECTOR (series->values[1].data));
-	res = go_data_vector_get_len (
-		GO_DATA_VECTOR (series->values[1].data));
-	if (series->values[0].data) {
-		*x = go_data_vector_get_values (
-			GO_DATA_VECTOR (series->values[0].data));
-		nb = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->values[0].data));
-		if (res > nb)
-			res = nb;
 	}
-	return res;
+
+	n_points = gog_series_get_data (series, NULL, data, 2);
+
+	*x = data[0];
+	*y = data[1];
+
+	return n_points;
 }
+
+unsigned
+gog_series_get_xyz_data (GogSeries const  *series,
+			 double const 	 **x, 
+			 double const 	 **y, 
+			 double const 	 **z)
+{
+	double *data[3];
+	unsigned int n_points;
+
+	n_points = gog_series_get_data (series, NULL, data, 3);
+
+	*x = data[0];
+	*y = data[1];
+	*z = data[2];
+
+	return n_points;
+}
+
+GogSeriesFillType
+gog_series_get_fill_type (GogSeries const *series)
+{
+	g_return_val_if_fail (IS_GOG_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
+
+	return series->fill_type;
+}
+
+void
+gog_series_set_fill_type (GogSeries *series, GogSeriesFillType fill_type)
+{
+	GogSeriesClass *series_klass;
+
+	g_return_if_fail (IS_GOG_SERIES (series));
+	if (series->fill_type == fill_type)
+		return;
+	g_return_if_fail (fill_type >= 0 && fill_type < GOG_SERIES_FILL_TYPE_INVALID);
+
+	series_klass = GOG_SERIES_GET_CLASS (series);
+	g_return_if_fail (series_klass->valid_fill_type_list != NULL);
+
+	series->fill_type = fill_type;
+	gog_object_request_update (GOG_OBJECT (series));
+}
+
+#ifdef GOFFICE_WITH_GTK
+void
+gog_series_populate_fill_type_combo (GogSeries const *series, GtkComboBox *combo)
+{
+	GogSeriesClass *series_klass;
+	GogSeriesFillType fill_type;
+	unsigned int i;
+
+	g_return_if_fail (IS_GOG_SERIES (series));
+	series_klass = GOG_SERIES_GET_CLASS (series);
+	g_return_if_fail (series_klass->valid_fill_type_list != NULL);
+
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (combo)));
+	for (i = 0; series_klass->valid_fill_type_list[i] != GOG_SERIES_FILL_TYPE_INVALID; i++) {
+		fill_type = series_klass->valid_fill_type_list[i];
+		if (fill_type >= 0 && fill_type < GOG_SERIES_FILL_TYPE_INVALID) {
+			gtk_combo_box_append_text (combo, _(_fill_type_infos[fill_type].label));
+			if (fill_type == series->fill_type)
+				gtk_combo_box_set_active (combo, i);
+		}
+	}
+}
+
+GogSeriesFillType
+gog_series_get_fill_type_from_combo (GogSeries const *series, GtkComboBox *combo)
+{
+	GogSeriesClass *series_klass;
+
+	g_return_val_if_fail (IS_GOG_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
+	series_klass = GOG_SERIES_GET_CLASS (series);
+	g_return_val_if_fail (series_klass->valid_fill_type_list != NULL, GOG_SERIES_FILL_TYPE_INVALID);
+
+	return series_klass->valid_fill_type_list[gtk_combo_box_get_active (combo)];
+}
+#endif
