@@ -29,7 +29,7 @@
 
 #include <goffice/goffice-config.h>
 #include "go-color-palette.h"
-#include "goffice-gtk.h"
+#include <goffice/gtk/goffice-gtk.h>
 #include <goffice/utils/go-marshalers.h>
 
 #include <goffice/utils/go-color.h>
@@ -52,7 +52,6 @@ struct _GOColorPalette {
 
 	/* only for custom colours */
 	GtkWidget   *swatches [GO_COLOR_GROUP_HISTORY_SIZE];
-	GtkTooltips *tip;
 
 	/* The table with our default color names */
 	GONamedColor const *default_set;
@@ -197,11 +196,6 @@ go_color_palette_finalize (GObject *object)
 {
 	GOColorPalette *pal = GO_COLOR_PALETTE (object);
 
-	if (pal->tip) {
-		g_object_unref (pal->tip);
-		pal->tip = NULL;
-	}
-
 	go_color_palette_set_group (pal, NULL);
 
 	(*go_color_palette_parent_class->finalize) (object);
@@ -334,8 +328,9 @@ cb_swatch_key_press (GtkBin *button, GdkEventKey *event, GOColorPalette *pal)
  * Utility function
  */
 static GtkWidget *
-go_color_palette_button_new (GOColorPalette *pal, GtkTable* table, GtkTooltips *tip,
-			     GONamedColor const * color_name, gint col, gint row)
+go_color_palette_button_new (GOColorPalette *pal, GtkTable* table,
+			     GONamedColor const *color_name,
+			     gint col, gint row)
 {
         GtkWidget *button, *swatch, *box;
 	GdkColor   gdk;
@@ -353,7 +348,7 @@ go_color_palette_button_new (GOColorPalette *pal, GtkTable* table, GtkTooltips *
 	button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
 	gtk_container_add (GTK_CONTAINER (button), box);
-	gtk_tooltips_set_tip (tip, button, _(color_name->name), "");
+	go_widget_set_tooltip_text (button, _(color_name->name));
 
 	gtk_table_attach (table, button, col, col+1, row, row+1,
 		GTK_FILL, GTK_FILL, 0, 0);
@@ -393,30 +388,32 @@ go_color_palette_set_title (GOColorPalette *pal, char const *title)
 
 /**
  * go_color_palette_set_group :
+ * @p : #GOColorPalette
  * @cg : #GOColorGroup
  *
- * Absorb the reference to the group
- */
+ * Absorbs the reference to the group
+ **/
 void
-go_color_palette_set_group (GOColorPalette *pal, GOColorGroup *cg)
+go_color_palette_set_group (GOColorPalette *p, GOColorGroup *cg)
 {
-	if (pal->group == cg)
+	if (p->group == cg)
 		return;
 
-	if (pal->group) {
+	if (p->group) {
 		g_signal_handlers_disconnect_by_func (
-			G_OBJECT (pal->group),
-			G_CALLBACK (cb_history_changed), pal);
-		g_object_unref (G_OBJECT (pal->group));
-		pal->group = NULL;
+			G_OBJECT (p->group),
+			G_CALLBACK (cb_history_changed), p);
+		g_object_unref (G_OBJECT (p->group));
+		p->group = NULL;
 	}
 	if (cg != NULL) {
-		pal->group = cg;
+		p->group = cg;
 		g_signal_connect_swapped (G_OBJECT (cg),
 			"history-changed",
-			G_CALLBACK (cb_history_changed), pal);
+			G_CALLBACK (cb_history_changed), p);
 	}
 }
+
 static GtkWidget *
 go_color_palette_setup (GOColorPalette *pal,
 		     char const *no_color_label,
@@ -424,7 +421,6 @@ go_color_palette_setup (GOColorPalette *pal,
 		     GONamedColor const *color_names)
 {
 	GtkWidget	*w, *table;
-	GtkTooltips	*tip;
 	int pos, row, col = 0;
 
 	table = gtk_table_new (cols, rows, FALSE);
@@ -438,21 +434,13 @@ go_color_palette_setup (GOColorPalette *pal,
 			G_CALLBACK (cb_default_release_event), pal);
 	}
 
-	pal->tip = tip = gtk_tooltips_new ();
-#if GLIB_CHECK_VERSION(2,10,0) && GTK_CHECK_VERSION(2,8,14)
-	g_object_ref_sink (pal->tip);
-#else
-	g_object_ref (pal->tip);
-	gtk_object_sink (GTK_OBJECT (pal->tip));
-#endif
-
 	for (row = 0; row < rows; row++)
 		for (col = 0; col < cols; col++) {
 			pos = row * cols + col;
 			if (color_names [pos].name == NULL)
 				goto custom_colors;
 			go_color_palette_button_new ( pal,
-				GTK_TABLE (table), GTK_TOOLTIPS (tip),
+				GTK_TABLE (table),
 				&(color_names [pos]), col, row + 1);
 		}
 
@@ -463,7 +451,7 @@ custom_colors :
 		GONamedColor color_name = { 0, N_("custom") };
 		color_name.color = pal->group->history [col];
 		pal->swatches [col] = go_color_palette_button_new (pal,
-			GTK_TABLE (table), GTK_TOOLTIPS (tip),
+			GTK_TABLE (table),
 			&color_name, col, row + 1);
 	}
 
@@ -510,10 +498,18 @@ go_color_palette_set_allow_alpha (GOColorPalette *pal, gboolean allow_alpha)
 	pal->allow_alpha = allow_alpha;
 }
 
+/**
+ * go_color_palette_new:
+ * @no_color_label: color label
+ * @default_color: #GOColor
+ * @cg: #GOColorGroup
+ *
+ * Returns: A new palette
+ **/
 GtkWidget *
 go_color_palette_new (char const *no_color_label,
-		   GOColor default_color,
-		   GOColorGroup *cg)
+		      GOColor default_color,
+		      GOColorGroup *cg)
 {
 	GOColorPalette *pal;
 	int const cols = 8;
@@ -587,9 +583,16 @@ make_colored_menu_item (char const *label, GOColor c)
 		COLOR_PREVIEW_WIDTH, COLOR_PREVIEW_HEIGHT);
 	gdk_pixbuf_fill (pixbuf, c);
 
-	button = gtk_image_menu_item_new_with_label (label);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (button),
-		gtk_image_new_from_pixbuf (pixbuf));
+	if (label && 0 == strcmp (label, " ")) {
+		/* color buttons are created with a label of " " */
+		button = gtk_menu_item_new ();
+		gtk_container_add (GTK_CONTAINER (button), 
+			gtk_image_new_from_pixbuf (pixbuf));
+	} else {
+		button = gtk_image_menu_item_new_with_label (label);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (button),
+			gtk_image_new_from_pixbuf (pixbuf));
+	}
 	g_object_unref (pixbuf);
 	gtk_widget_show_all (button);
 
@@ -638,14 +641,14 @@ cb_menu_custom_activate (GtkWidget *button, GOMenuColor *menu)
 
 /**
  * go_color_palette_make_menu:
- * @no_color_labe :
- * default_color: #GOColor
- * @cg : #GOColorGroup
- * @custom_dialog_title :
+ * @no_color_label: color label
+ * @default_color: #GOColor
+ * @cg: #GOColorGroup
+ * @custom_dialog_title : optional string
  * @current_color : #GOColor
  *
- * Create a submenu with a palette of colours.  Caller is responsible for
- * creating an item to point to the submenu.
+ * Returns:  a submenu with a palette of colours.  Caller is responsible for
+ * 	creating an item to point to the submenu.
  **/
 GtkWidget *
 go_color_palette_make_menu (char const *no_color_label,
